'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = _interopDefault(require('react'));
var PropTypes = _interopDefault(require('prop-types'));
var FlexGrid = _interopDefault(require('@tds/core-flex-grid'));
var DecorativeIcon = _interopDefault(require('@tds/core-decorative-icon'));
var Paragraph = _interopDefault(require('@tds/core-paragraph'));
var Box = _interopDefault(require('@tds/core-box'));

var _extends = Object.assign || function (target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i];

    for (var key in source) {
      if (Object.prototype.hasOwnProperty.call(source, key)) {
        target[key] = source[key];
      }
    }
  }

  return target;
};

var objectWithoutProperties = function (obj, keys) {
  var target = {};

  for (var i in obj) {
    if (keys.indexOf(i) >= 0) continue;
    if (!Object.prototype.hasOwnProperty.call(obj, i)) continue;
    target[i] = obj[i];
  }

  return target;
};

var safeRest = (function (_ref) {
  var style = _ref.style,
      className = _ref.className,
      props = objectWithoutProperties(_ref, ["style", "className"]);
  return props;
});

var styles = { "instructional": "TDS_Notification-modules__instructional___1XRsw TDS_Messaging-modules__default___2B8Di", "branded": "TDS_Notification-modules__branded___3bfSl", "success": "TDS_Notification-modules__success___2_46M TDS_Messaging-modules__success___3kyw2", "error": "TDS_Notification-modules__error___JV-5X TDS_Messaging-modules__error___3NArF" };

var iconByVariant = {
  success: {
    symbol: 'checkmark',
    color: 'primary'
  },
  error: {
    symbol: 'exclamationPointCircle',
    color: 'error'
  }
};

var isImportant = function isImportant(variant) {
  return variant === 'success' || variant === 'error';
};

var renderIcon = function renderIcon(icon) {
  return React.createElement(DecorativeIcon, { symbol: icon.symbol, variant: icon.color });
};

/**
 * A banner that highlights important messages.
 *
 * @version ./package.json
 */
var Notification = function Notification(_ref) {
  var variant = _ref.variant,
      children = _ref.children,
      rest = objectWithoutProperties(_ref, ['variant', 'children']);
  return React.createElement(
    Box,
    _extends({}, safeRest(rest), { vertical: 3, dangerouslyAddClassName: styles[variant] }),
    React.createElement(
      FlexGrid,
      null,
      React.createElement(
        FlexGrid.Row,
        null,
        React.createElement(
          FlexGrid.Col,
          null,
          React.createElement(
            Box,
            { inline: true, between: 3 },
            isImportant(variant) ? renderIcon(iconByVariant[variant]) : undefined,
            React.createElement(
              Paragraph,
              { bold: isImportant(variant) },
              children
            )
          )
        )
      )
    )
  );
};

Notification.propTypes = {
  /**
   * The appearance.
   */
  variant: PropTypes.oneOf(['instructional', 'branded', 'success', 'error']),
  /**
   * The message. Can be raw text or text components.
   */
  children: PropTypes.node.isRequired
};

Notification.defaultProps = {
  variant: 'instructional'
};

module.exports = Notification;
//# sourceMappingURL=index.cjs.js.map
